@@ -1,8 +1,10 @@
-from .main import neo4j_graphql, cypher_query
+from .main import neo4j_graphql, cypher_query, cypher_mutation, augment_schema
 from .utils import make_executable_schema
 
 __all__ = [
     "neo4j_graphql",
     "cypher_query",
+    "cypher_mutation",
+    "augment_schema",
     "make_executable_schema",
 ]
